from MacroMoleculeAtom import MacroMoleculeAtom

class MacroMolecule(list):
    """
    Class MacroMolecule

    Examples:
    >>> from MacroMolecule import MacroMolecule
    >>> M = MacroMolecule()
    >>> M.atom_input(1, 'ALA', 'A', 1, '  O ', 'O', 0.0, 0.0, 0.0, 1, 0)
    >>> M.atom_input(1, 'ALA', 'A', 2, '  C ', 'C', 3.0, 0.0, 0.0, 1, 0)
    >>> len(M)
    2
    >>> len(M.polar_atoms)
    1
    >>> len(M.apolar_atoms)
    1

    """

    def atom_input(self, resOrgId, resType, chain, atomOriginalId,
                   atomOriginalName, atomType, x, y, z, subAtomType,
                   moleculeInstance):
        """function atom_input
        
        resOrgId: int
        resType: string
        chain: char
        atomOriginalId: int
        AtomOriginalName: string
        atomType: string
        x: float
        y: float
        z: float
        subAtomType: int
        moleculeInstance: int

        This method is used to input a new MacroMoleculeAtom into the
        __atomList.

        See the MacroMoleculeAtom and the Atom class for explanations of the
        agruments passed into this method.

        """
        self.append(MacroMoleculeAtom(atomOriginalId,
                                      atomOriginalName,
                                      atomType,
                                      x, y, z,
                                      subAtomType,
                                      moleculeInstance,
                                      resOrgId,
                                      resType,
                                      chain))
        self[-1].include = 1
    
    @property
    def polar_atoms(self):
        """
        Return list of polar atoms.
        """
        polarList = []
        for atom in self:
            if atom.atom_polarity == 0:
                polarList.append(atom)
        return polarList
    
    @property
    def apolar_atoms(self):
        """
        Return list of apolar atoms.
        """
        apolarList = []
        for atom in self:
            if atom.atom_polarity == 2:
                apolarList.append(atom)
        return apolarList
    
    def clear(self):
        """
        Clear list.

        Including neighbor lists and surface points.

        """
        for atom in self:
            atom.clear_neighbors()
            atom.clear_surface()
        del self[:]
        

# Test MacroMolecule class by 'python MacroMolecule.py'
if __name__ == "__main__":
    import doctest
    doctest.testmod()
